package com.huimv.eartag2.manage2.schedule;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.huimv.eartag2.manage2.pojo.EartagDeviceRegister;
import com.huimv.eartag2.manage2.pojo.SysBaseConfig;
import com.huimv.eartag2.manage2.service.EartagDeviceRegisterService;
import com.huimv.eartag2.manage2.service.IEartagService;
import com.huimv.eartag2.manage2.service.SysBaseConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import java.io.IOException;
import java.sql.Timestamp;
import java.text.ParseException;
import java.util.Date;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Configuration      //1.主要用于标记配置类，兼备Component的效果。
@EnableScheduling   // 2.开启定时任务
public class EartagTask {

    @Autowired
    private IEartagService eartagService;

    @Autowired
    private SysBaseConfigService baseConfigService;

    @Autowired
    private EartagDeviceRegisterService deviceRegisterService;

    /**
     * @Method      : countEartagOnlineTimes
     * @Description : 判断耳标离线状态
     * @Params      : []
     * @Return      : void
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/8/20
     * @Time        : 19:35
     */
    // 10分钟
    @Scheduled(cron = "0 0/10 * * * ? ")
    private void countEartagOnlineTimes() throws IOException, ParseException {
        Timestamp nowTimestamp = new Timestamp(new java.util.Date().getTime());
        System.out.println("时间戳="+nowTimestamp);

//        ExecutorService service = Executors.newFixedThreadPool(5);
//        ExecutorService service = Executors.newSingleThreadExecutor();
//        RunnableTaskEartagOnlineStatus task1 = new RunnableTaskEartagOnlineStatus();
//        service.execute(task1);
        //更新耳标在线状态
        eartagService.updateEartagLiveStatusAndCount();
    }


    /**
     * @Method      : updateDevice
     * @Description : 判断设备离线状态
     * @Params      : []
     * @Return      : void
     *
     * @Author      : ZhuoNing
     * @Date        : 2022/8/20
     * @Time        : 19:36
     */
    // 5分钟
    @Scheduled(cron = "0 0/5 * * * ? ")
    private void updateDevice()  {
        SysBaseConfig baseConfig = baseConfigService.getById(60);

        String configValueStr = baseConfig.getConfigValue();
        if (StringUtils.isNotBlank(configValueStr)){
            int configValueInt = Integer.parseInt(configValueStr);
            DateTime dateTime = DateUtil.offsetMinute(new Date(), -configValueInt);

            UpdateWrapper<EartagDeviceRegister> wrapper = new UpdateWrapper<>();
            wrapper.ge("last_time",dateTime);
            EartagDeviceRegister deviceRegister = new EartagDeviceRegister();
            //未离线
            deviceRegister.setActiveStatus(1);
            deviceRegister.setDeviceStatus(1);
            deviceRegisterService.update(deviceRegister,wrapper);

            //离线
            deviceRegister.setActiveStatus(2);
            deviceRegister.setDeviceStatus(0);
            wrapper.clear();
            wrapper.le("last_time",dateTime);
            deviceRegisterService.update(deviceRegister,wrapper);
        }else {
            System.out.println("未设置定时时长");
        }

        System.out.println("测试数据");
    }
}
